<p align="center">
  <picture width="200px">
    <source srcset="https://wasi-master.github.io/assets/img/project_logos/charinfo.avif" type="image/avif" width="200px">
    <source srcset="https://wasi-master.github.io/assets/img/project_logos/charinfo.webp" type="image/webp" width="200px">
    <img src="https://wasi-master.github.io/assets/img/project_logos/charinfo.png" width="200px">
</picture>
</p>
<h1 align="center">CharInfo</h1>
<p align="center">
 <a href="http://mypy-lang.org/"> <img alt="Mypy checked" src="http://www.mypy-lang.org/static/mypy_badge.svg"></a>
 <a href="https://pepy.tech/badge/charinfo"><img alt="Downloads" src="https://pepy.tech/badge/charinfo"></a>
 <a href="https://pepy.tech/badge/charinfo"><img alt="Downloads" src="https://pepy.tech/badge/charinfo/month"></a>
 <a href="https://pepy.tech/badge/charinfo"><img alt="Downloads" src="https://pepy.tech/badge/charinfo/week"></a>
 <img alt="Libraries.io dependency status for latest release" src="https://img.shields.io/librariesio/release/pypi/charinfo">
 <img alt="Lines of code" src="https://img.shields.io/tokei/lines/github/wasi-master/charinfo">
 <img alt="Repo size" src="https://img.shields.io/github/repo-size/wasi-master/charinfo">
 <img alt="Code size" src="https://img.shields.io/github/code-size/wasi-master/charinfo">
 <a href="https://github.com/wasi-master/charinfo/issues?q=is%3Aissue+is%3Aopen+sort%3Aupdated-desc"><img alt="GitHub issues" src="https://img.shields.io/github/issues-raw/wasi-master/charinfo"></a>
 <a href="https://github.com/wasi-master/charinfo/pulls?q=is%3Apr+is%3Aopen+sort%3Aupdated-desc"><img alt="GitHub pull requests" src="https://img.shields.io/github/issues-pr-raw/wasi-master/charinfo"></a>
 <a href="https://github.com/wasi-master/charinfo/blob/main/LICENSE"><img alt="License" src="https://img.shields.io/github/license/wasi-master/charinfo"></a>
 <a href="https://pypi.org/project/charinfo/#history"><img alt="Version" src="https://img.shields.io/pypi/v/charinfo"></a>
 <a href="https://keybase.io/wasimaster"><img alt="BTC Address" src="https://img.shields.io/keybase/btc/wasimaster"></a>
 <a href="https://keybase.io/wasimaster"><img alt="ZCash Address" src="https://img.shields.io/keybase/zec/wasimaster"></a>
 <a href="https://github.com/wasi-master/charinfo/commits/main"><img alt="Last commit" src="https://img.shields.io/github/last-commit/wasi-master/charinfo"></a>
 <!-- <img alt="" src="">
 <a href=""><img alt="" src=""></a> -->
</p>
<p align="center">
 A command line tool to view detailed information about a character
</p>

## Screenshots

Hover over them to know their description

![Directly passing the character](https://raw.githubusercontent.com/wasi-master/charinfo/main/images/usage_direct.png "Directly passing the character")
![Directly passing multiple characters](https://raw.githubusercontent.com/wasi-master/charinfo/main/images/usage_multiple.png "Directly passing multiple characters")
![Passing the name of the character](https://raw.githubusercontent.com/wasi-master/charinfo/main/images/usage_name.png "Passing the name of the character")
![Passing the name of multiple characters](https://raw.githubusercontent.com/wasi-master/charinfo/main/images/usage_name_multiple.png "Passing the name of multiple characters")
![Passing the unicode codepoint of the character](https://raw.githubusercontent.com/wasi-master/charinfo/main/images/usage_unicode.png "Passing the unicode codepoint of the character")
![Passing the decimal representation of the unicode codepoint of the character](https://raw.githubusercontent.com/wasi-master/charinfo/main/images/usage_decimal.png "Passing the decimal representation of the unicode codepoint of the character")
